package com.tanpu.community.controller;

import com.tanpu.common.util.JsonUtil;
import com.tanpu.community.manager.FileManager;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Date;
import java.util.HashMap;
import java.util.Map;

@RestController
@Slf4j
@RequestMapping(value = "/api")
public class CallBackController {

    @Autowired
    private FileManager fileManager;

    /**
     * 阿里云图片审核回调接口
     * 回调时间：6秒以内
     * 文档地址：https://help.aliyun.com/document_detail/129946.html?spm=a2c4g.11186623.6.562.19a05f3aNkd2Oo#table-s9e-grd-408
     * @param checksum
     * @param content
     * @return
     */
    @ApiOperation("oss图片审核回调")
    @PostMapping(value = "/picCheck/callback")
    public String picCheck(String checksum,String content) {

        log.info("checksum:{}", checksum);
        Map<String, Object> response = JsonUtil.toMap(content);
        String fileKey = (String) response.get("object");
        boolean freezed = (boolean) response.get("freezed");
        HashMap<String,Object> scanResult = (HashMap<String, Object>) response.get("scanResult");
        String taskId = (String) scanResult.get("taskId");
        fileManager.updateCheckResult(fileKey,freezed,taskId);
        return "success";
    }

    public static void main(String[] args) {
        System.out.println(new Date());
    }


}
